@@ -1,5 +1,5 @@
 use {
-    crate::{state::*, errors::*},
+    crate::{state::*, errors::ErrorCode},
     anchor_lang::{prelude::*, solana_program::program::invoke_signed, AccountsClose},
     anchor_spl::{token::{self, Token, TokenAccount, Mint, Transfer, FreezeAccount, Approve}},
     mpl_token_metadata::{instruction::freeze_delegated_account, utils::assert_derivation},
@@ -30,7 +30,7 @@ pub struct ClaimCtx<'info> {
     token_program: Program<'info, Token>,
 }
 
-pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts, 'remaining, 'info, ClaimCtx<'info>>) -> ProgramResult {
+pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts, 'remaining, 'info, ClaimCtx<'info>>) -> Result<()> {
     let token_manager = &mut ctx.accounts.token_manager;
     token_manager.recipient_token_account = ctx.accounts.recipient_token_account.key();
     token_manager.state = TokenManagerState::Claimed as u8;
@@ -87,7 +87,7 @@ pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts,
 
         // edition will be validated by metadata_program
         // assert_keys_eq!(metadata_program.key, mpl_token_metadata::id());
-        if metadata_program.key() != mpl_token_metadata::id() { return Err(ErrorCode::PublicKeyMismatch.into()); }
+        if metadata_program.key() != mpl_token_metadata::id() { return Err(error!(ErrorCode::PublicKeyMismatch)); }
 
         // set account delegate of recipient token account to token manager PDA
         let cpi_accounts = Approve {
@@ -128,7 +128,7 @@ pub fn handler<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts,
             recipient_key.as_ref(),
         ];
         let (claim_receipt_address, _bump) = Pubkey::find_program_address(seed, ctx.program_id);
-        if claim_receipt_address != claim_receipt_info.key() { return Err(ErrorCode::InvalidClaimReceipt.into()); }
+        if claim_receipt_address != claim_receipt_info.key() { return Err(error!(ErrorCode::InvalidClaimReceipt)); }
         // assert_keys_eq!(claim_receipt_address, claim_receipt_info.key());
         let claim_receipt = Account::<ClaimReceipt>::try_from(claim_receipt_info)?;
         claim_receipt.close(token_manager.to_account_info())?;
